@@ -1,14 +1,15 @@
 msmedse <-
-function(x){
+function(x, sewarn = TRUE){
 #
 # Compute  standard error of the median using method
 # recommended by McKean and Shrader (1984).
 #
 x=elimna(x)
 chk=sum(duplicated(x))
+if (sewarn) {
 if(chk>0){
-warning("Tied values detected. Estimate of standard error might be highly inaccurate, even with n large")
-}
+warning("Tied values detected. Estimate of standard error might be inaccurate, even with n large")
+}}
 y<-sort(x)
 n<-length(x)
 av<-round((n+1)/2-qnorm(.995)*sqrt(n/4))
